# mindstorm

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

An experimental library to build LLM societies. 


## Install

``` sh
pip install mindstorm
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
